pub enum BoundaryKind {
Inclusive,
Exclusive,
}Expand description
How to interpret the value of a boundary.
Variants
Inclusive
Use inclusive comparisons such as >= and <=, the value listed in the term should match the result set.
Exclusive
Use exclusive comparisons such as > and <, the value listed in the term should not match the result set.